package org.apache.maven.j2ee;

/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *    "Apache Maven" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    "Apache Maven", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

import junit.framework.TestCase;

/**
 * Test cases for the {@link ValidationBroadcaster}
 *
 * @author <a href="mailto:dion@multitask.com.au">dIon Gillard</a>
 * @version $Id$
 */
public class ValidationBroadcasterTest extends TestCase
{
    /** instance for unit testing */
    private ValidationBroadcaster instance;
    /** listener used to check status/events firing */
    private ValidationStatusListener status;
    
    /** 
     * Creates a new instance of ValidationBroadcasterTest
     * @param testName the name of the test
     */
    public ValidationBroadcasterTest(String testName)
    {
        super(testName);
    }

    /**
     * Initialize per test data
     * @throws Exception when there is an unexpected problem
     */
    public void setUp() throws Exception
    {
        setInstance(new ValidationBroadcaster());
        setStatus(new ValidationStatusListener());
        getInstance().addValidationListener(getStatus());
    }
    
    /**
     * test that the fireStartedEvent method works
     * @throws Exception when there is an unexpected problem
     */
    public void testStartedBroadcast() throws Exception
    {
        assertTrue("status was started before starting",
            !getStatus().isStarted());
        getInstance().fireStartedEvent(new ValidationEvent(this));
        assertTrue("status was not started after broadcast", 
            getStatus().isStarted());
    }

    /**
     * test that the fireErrorEvent method works
     * @throws Exception when there is an unexpected problem
     */
    public void testErrorBroadcast() throws Exception
    {
        assertTrue("status was error before starting", 
            !getStatus().isError());
        getInstance().fireErrorEvent(new ValidationEvent(this));
        assertTrue("status was not error after broadcast", 
            getStatus().isError());
    }

    /**
     * test that the fireErrorEvent method works
     * @throws Exception when there is an unexpected problem
     */
    public void testWarningBroadcast() throws Exception
    {
        assertTrue("status was warning before starting", 
            !getStatus().isWarning());
        getInstance().fireWarningEvent(new ValidationEvent(this));
        assertTrue("status was not warning after broadcast", 
            getStatus().isWarning());
    }

    /**
     * test that the fireEndedEvent method works
     * @throws Exception when there is an unexpected problem
     */
    public void testEndedBroadcast() throws Exception
    {
        assertTrue("status was ended before starting", 
            !getStatus().isEnded());
        getInstance().fireEndedEvent(new ValidationEvent(this));
        assertTrue("status was not ended after broadcast", 
            getStatus().isEnded());
    }
    
    /**
     * test that the removeValidationListeners method works
     * @throws Exception when there is an unexpected problem
     */
    public void testRemoveListener() throws Exception
    {
        assertTrue("status was started before starting", 
            !getStatus().isStarted());
        getInstance().removeValidationListener(getStatus());
        getInstance().fireStartedEvent(new ValidationEvent(this));
        assertTrue("event received after removing", !getStatus().isStarted());
    }

    /** Getter for property instance.
     * @return Value of property instance.
     */
    private ValidationBroadcaster getInstance()
    {
        return instance;
    }
    
    /** Setter for property instance.
     * @param instance New value of property instance.
     */
    private void setInstance(ValidationBroadcaster instance)
    {
        this.instance = instance;
    }
    
    /** Getter for property status.
     * @return Value of property status.
     */
    private ValidationStatusListener getStatus()
    {
        return status;
    }
    
    /** Setter for property status.
     * @param status New value of property status.
     */
    private void setStatus(ValidationStatusListener status)
    {
        this.status = status;
    }
    
}
